@@ -30,7 +30,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Dict, Generator, List, TYPE_CHECKING
+from typing import Dict, Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_codedeploy.type_defs import (
     ListApplicationRevisionsOutputTypeDef,
@@ -68,7 +68,7 @@ __all__ = (
 
 class ListApplicationRevisionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListApplicationRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)
+    [Paginator.ListApplicationRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)
     """
 
     def paginate(
@@ -80,54 +80,54 @@ class ListApplicationRevisionsPaginator(Boto3Paginator):
         s3KeyPrefix: str = None,
         deployed: Literal["include", "exclude", "ignore"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListApplicationRevisionsOutputTypeDef, None, None]:
+    ) -> Iterator[ListApplicationRevisionsOutputTypeDef]:
         """
-        [ListApplicationRevisions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions.paginate)
+        [ListApplicationRevisions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions.paginate)
         """
 
 
 class ListApplicationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)
+    [Paginator.ListApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListApplicationsOutputTypeDef, None, None]:
+    ) -> Iterator[ListApplicationsOutputTypeDef]:
         """
-        [ListApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications.paginate)
+        [ListApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications.paginate)
         """
 
 
 class ListDeploymentConfigsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDeploymentConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)
+    [Paginator.ListDeploymentConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDeploymentConfigsOutputTypeDef, None, None]:
+    ) -> Iterator[ListDeploymentConfigsOutputTypeDef]:
         """
-        [ListDeploymentConfigs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs.paginate)
+        [ListDeploymentConfigs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs.paginate)
         """
 
 
 class ListDeploymentGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDeploymentGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)
+    [Paginator.ListDeploymentGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)
     """
 
     def paginate(
         self, applicationName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDeploymentGroupsOutputTypeDef, None, None]:
+    ) -> Iterator[ListDeploymentGroupsOutputTypeDef]:
         """
-        [ListDeploymentGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups.paginate)
+        [ListDeploymentGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups.paginate)
         """
 
 
 class ListDeploymentInstancesPaginator(Boto3Paginator):
     """
-    [Paginator.ListDeploymentInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)
+    [Paginator.ListDeploymentInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)
     """
 
     def paginate(
@@ -138,15 +138,15 @@ class ListDeploymentInstancesPaginator(Boto3Paginator):
         ] = None,
         instanceTypeFilter: List[Literal["Blue", "Green"]] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListDeploymentInstancesOutputTypeDef, None, None]:
+    ) -> Iterator[ListDeploymentInstancesOutputTypeDef]:
         """
-        [ListDeploymentInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances.paginate)
+        [ListDeploymentInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances.paginate)
         """
 
 
 class ListDeploymentTargetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDeploymentTargets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)
+    [Paginator.ListDeploymentTargets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)
     """
 
     def paginate(
@@ -154,15 +154,15 @@ class ListDeploymentTargetsPaginator(Boto3Paginator):
         deploymentId: str = None,
         targetFilters: Dict[Literal["TargetStatus", "ServerInstanceLabel"], List[str]] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListDeploymentTargetsOutputTypeDef, None, None]:
+    ) -> Iterator[ListDeploymentTargetsOutputTypeDef]:
         """
-        [ListDeploymentTargets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets.paginate)
+        [ListDeploymentTargets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets.paginate)
         """
 
 
 class ListDeploymentsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDeployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)
+    [Paginator.ListDeployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)
     """
 
     def paginate(
@@ -174,28 +174,28 @@ class ListDeploymentsPaginator(Boto3Paginator):
         ] = None,
         createTimeRange: TimeRangeTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListDeploymentsOutputTypeDef, None, None]:
+    ) -> Iterator[ListDeploymentsOutputTypeDef]:
         """
-        [ListDeployments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments.paginate)
+        [ListDeployments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments.paginate)
         """
 
 
 class ListGitHubAccountTokenNamesPaginator(Boto3Paginator):
     """
-    [Paginator.ListGitHubAccountTokenNames documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)
+    [Paginator.ListGitHubAccountTokenNames documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListGitHubAccountTokenNamesOutputTypeDef, None, None]:
+    ) -> Iterator[ListGitHubAccountTokenNamesOutputTypeDef]:
         """
-        [ListGitHubAccountTokenNames.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames.paginate)
+        [ListGitHubAccountTokenNames.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames.paginate)
         """
 
 
 class ListOnPremisesInstancesPaginator(Boto3Paginator):
     """
-    [Paginator.ListOnPremisesInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)
+    [Paginator.ListOnPremisesInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)
     """
 
     def paginate(
@@ -203,7 +203,7 @@ class ListOnPremisesInstancesPaginator(Boto3Paginator):
         registrationStatus: Literal["Registered", "Deregistered"] = None,
         tagFilters: List[TagFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListOnPremisesInstancesOutputTypeDef, None, None]:
+    ) -> Iterator[ListOnPremisesInstancesOutputTypeDef]:
         """
-        [ListOnPremisesInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances.paginate)
+        [ListOnPremisesInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances.paginate)
         """
